/*
 * Copyright 2005-2006 Myriad Genetics, Inc.
 *
 * All rights reserved.
 */

package com.myriad.tmap.grouping;

import java.awt.*;
import java.util.ArrayList;
import java.util.Arrays;

/** This class represents a list of markers which are all linked together even
    at the maximum LOD threshold.
 */
class LinkGroupCluster extends LinkGroupNode {
    public LinkGroupCluster(Marker[] aMarkers)
    {
        markers = aMarkers;
        Arrays.sort(markers);
    }
    
    public int position(int upperBound)
    {
        int     bound = upperBound;
        int     top = 0;
        
        for (int i = 0; i < markers.length; ++i)
            bound = markers[i].position(bound);
        
        return bound;
    }
    
    public Point paint(Graphics2D g, DisplayParameters params, int t, int b)
    {
        int     top = 0;
        Point   p = null;
        
        for (int i = 0; i < markers.length; ++i) {
            p = markers[i].paint(g, params, t, b);
            if (i == 0)
                top = p.y;
            
            setPaintColor(g);
            g.drawLine(params.markerX, p.y, p.x, p.y);
        }
        
        g.drawLine(params.markerX, top, params.markerX, p.y);
        
        return new Point(params.markerX, (top + p.y) / 2);
    }
    
    public int getPreferredHeight()
    {
        int     prefHeight = 0;
        
        for (int i = 0; i < markers.length; ++i)
            prefHeight += markers[i].getPreferredHeight();
        return prefHeight;
    }
    
    public LinkGroupNode findNodeForPoint(Point p, DisplayParameters params)
    {
        if (p.x <= params.markerX)
            return this;
        
        /* Morally, we should only pass the method onto the correct child,
           as LinkGroupMerge does, but we're lazy and we know that all the
           children are Marker, which will check the y coordinate themselves.
         */
        for (int i = 0; i < markers.length; ++i) {
            LinkGroupNode   res = markers[i].findNodeForPoint(p, params);
            
            if (res != null)
                return res;
        }
        return null;
    }
    
    public Marker findMarkerByName(String name)
    {
        for (int i = 0; i < markers.length; ++i) {
            Marker  mark = markers[i].findMarkerByName(name);
            
            if (mark != null)
                return mark;
        }
        return null;
    }
    
    void setSelected(boolean sel)
    {
        for (int i = 0; i < markers.length; ++i)
            markers[i].setSelected(sel);
    }
    
    boolean isAllSelected()
    {
        for (int i = 0; i < markers.length; ++i) {
            if (!markers[i].isAllSelected())
                return false;
        }
        return true;
    }
    
    protected void getMarkerList(ArrayList acc, boolean sel)
    {
        for (int i = 0; i < markers.length; ++i)
            markers[i].getMarkerList(acc, sel);
    }
    
    private Marker[]    markers;
}
